==> touhoulittlemaid-fabric-1.20.1-0.1.2-forge1.3.7-sources.jar: com/github/tartaricacid/touhoulittlemaid/compat/tacz/TacCompat.java <==
package com.github.tartaricacid.touhoulittlemaid.compat.tacz;

import com.github.tartaricacid.touhoulittlemaid.api.entity.IMaid;
import com.github.tartaricacid.touhoulittlemaid.client.animation.script.ModelRendererWrapper;
import com.github.tartaricacid.touhoulittlemaid.client.entity.GeckoMaidEntity;
import com.github.tartaricacid.touhoulittlemaid.entity.task.TaskManager;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.core.PlayState;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.core.builder.ILoopType;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.core.event.predicate.AnimationEvent;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.geo.animated.ILocationModel;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import javax.annotation.Nullable;

public class TacCompat {
    public static final class_2960 MINIGUN_ID = new class_2960("tacz", "minigun");
    private static final String TACZ_ID = "tacz";
    private static boolean INSTALLED = false;

    public static void initAndAddGunTask(TaskManager manager) {
        if (FabricLoader.getInstance().isModLoaded(TACZ_ID)) {
//            MinecraftForge.EVENT_BUS.register(new GunHurtMaidEvent());
//            MinecraftForge.EVENT_BUS.register(new MaidGunEquipEvent());
//            manager.add(new TaskGunAttack());
            INSTALLED = true;
        }
    }

    public static boolean isInstalled() {
        return INSTALLED;
    }

    public static boolean isGun(class_1799 stack) {
        if (INSTALLED) {
            // return TacInnerCompat.isGun(stack);
        }
        return false;
    }

    public static boolean isGrenade(class_1799 itemStack) {
        // TODO 手雷还没有
        return false;
    }

    @Nullable
    public static class_2960 getGunId(class_1799 stack) {
        if (INSTALLED) {
            // return TacInnerCompat.getGunId(stack);
        }
        return null;
    }

    @Environment(EnvType.CLIENT)
    public static boolean onHoldGun(IMaid maid, @Nullable ModelRendererWrapper armLeft, @Nullable ModelRendererWrapper armRight) {
        if (INSTALLED) {
            // return GunBaseAnimation.onHoldGun(maid, armLeft, armRight);
        }
        return false;
    }

    @Environment(EnvType.CLIENT)
    public static void addItemTranslate(class_4587 matrixStack, class_1799 itemStack, boolean isLeft) {
        if (INSTALLED) {
            // GunMaidRender.addItemTranslate(matrixStack, itemStack, isLeft);
        }
    }

    @Environment(EnvType.CLIENT)
    public static void renderBackGun(class_4587 matrixStack, class_4597 bufferIn, int packedLightIn, class_1799 stack, IMaid maid) {
        if (INSTALLED) {
            // GunMaidRender.renderBackGun(matrixStack, bufferIn, packedLightIn, stack, maid);
        }
    }

    @Environment(EnvType.CLIENT)
    public static void renderBackGun(class_1799 offhandItem, ILocationModel geoModel, IMaid maid, class_4587 poseStack, class_4597 bufferIn, int packedLight) {
        if (INSTALLED && isGun(offhandItem)) {
            poseStack.method_22903();
            // GunMaidRender.renderBackGun(offhandItem, geoModel, maid, poseStack, bufferIn, packedLight);
            poseStack.method_22909();
        }
    }

    @Environment(EnvType.CLIENT)
    @Nullable
    public static PlayState playGunMainAnimation(IMaid maid, AnimationEvent<GeckoMaidEntity<?>> event, String animationName, ILoopType loopType) {
        if (INSTALLED && isGun(maid.asEntity().method_6047())) {
            // return GunGeckoAnimation.playGunMainAnimation(event, animationName, loopType);
        }
        return null;
    }

    @Environment(EnvType.CLIENT)
    @Nullable
    public static PlayState playGunHoldAnimation(class_1799 mainHandItem, AnimationEvent<GeckoMaidEntity<?>> event) {
        if (INSTALLED && isGun(mainHandItem)) {
            // return GunGeckoAnimation.playGunHoldAnimation(event, mainHandItem);
        }
        return null;
    }
}

==> touhoulittlemaid-fabric-1.20.1-0.1.7-forge1.3.8-sources.jar: com/github/tartaricacid/touhoulittlemaid/compat/tacz/TacCompat.java <==
package com.github.tartaricacid.touhoulittlemaid.compat.tacz;

import cn.sh1rocu.touhoulittlemaid.api.event.ExplosionEvents;
import cn.sh1rocu.touhoulittlemaid.api.event.LivingAttackEvent;
import com.github.tartaricacid.touhoulittlemaid.api.entity.IMaid;
import com.github.tartaricacid.touhoulittlemaid.api.event.MaidEquipEvent;
import com.github.tartaricacid.touhoulittlemaid.api.event.MaidHurtEvent;
import com.github.tartaricacid.touhoulittlemaid.client.animation.script.ModelRendererWrapper;
import com.github.tartaricacid.touhoulittlemaid.client.entity.GeckoMaidEntity;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.client.GunBaseAnimation;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.client.GunGeckoAnimation;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.client.GunMaidRender;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.event.GunHurtMaidEvent;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.event.MaidGunEquipEvent;
import com.github.tartaricacid.touhoulittlemaid.compat.tacz.task.TaskGunAttack;
import com.github.tartaricacid.touhoulittlemaid.entity.task.TaskManager;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.core.PlayState;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.core.builder.ILoopType;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.core.event.predicate.AnimationEvent;
import com.github.tartaricacid.touhoulittlemaid.geckolib3.geo.animated.ILocationModel;
import com.tacz.guns.api.event.common.EntityHurtByGunEvent;
import net.fabricmc.api.EnvType;
import net.fabricmc.api.Environment;
import net.fabricmc.loader.api.FabricLoader;
import net.minecraft.class_1799;
import net.minecraft.class_2960;
import net.minecraft.class_4587;
import net.minecraft.class_4597;
import javax.annotation.Nullable;

public class TacCompat {
    public static final class_2960 MINIGUN_ID = new class_2960("tacz", "minigun");
    private static final String TACZ_ID = "tacz";
    private static boolean INSTALLED = false;

    public static void initAndAddGunTask(TaskManager manager) {
        if (FabricLoader.getInstance().isModLoaded(TACZ_ID)) {
            GunHurtMaidEvent gunHurtMaidEvent = new GunHurtMaidEvent();
            MaidHurtEvent.CALLBACK.register(gunHurtMaidEvent::onMaidHurt);
            EntityHurtByGunEvent.Pre.EVENT.register(gunHurtMaidEvent::onGunHurt);
            LivingAttackEvent.CALLBACK.register(gunHurtMaidEvent::onPlayerHurt);
            ExplosionEvents.DETONATE.register(gunHurtMaidEvent::onExplosionDetonateEvent);

            MaidGunEquipEvent maidGunEquipEvent = new MaidGunEquipEvent();
            MaidEquipEvent.CALLBACK.register(maidGunEquipEvent::onMaidEquip);

            manager.add(new TaskGunAttack());
            INSTALLED = true;
        }
    }

    public static boolean isInstalled() {
        return INSTALLED;
    }

    public static boolean isGun(class_1799 stack) {
        if (INSTALLED) {
            return TacInnerCompat.isGun(stack);
        }
        return false;
    }

    public static boolean isGrenade(class_1799 itemStack) {
        // TODO 手雷还没有
        return false;
    }

    @Nullable
    public static class_2960 getGunId(class_1799 stack) {
        if (INSTALLED) {
            return TacInnerCompat.getGunId(stack);
        }
        return null;
    }

    @Environment(EnvType.CLIENT)
    public static boolean onHoldGun(IMaid maid, @Nullable ModelRendererWrapper armLeft, @Nullable ModelRendererWrapper armRight) {
        if (INSTALLED) {
            return GunBaseAnimation.onHoldGun(maid, armLeft, armRight);
        }
        return false;
    }

    @Environment(EnvType.CLIENT)
    public static void addItemTranslate(class_4587 matrixStack, class_1799 itemStack, boolean isLeft) {
        if (INSTALLED) {
            GunMaidRender.addItemTranslate(matrixStack, itemStack, isLeft);
        }
    }

    @Environment(EnvType.CLIENT)
    public static void renderBackGun(class_4587 matrixStack, class_4597 bufferIn, int packedLightIn, class_1799 stack, IMaid maid) {
        if (INSTALLED) {
            GunMaidRender.renderBackGun(matrixStack, bufferIn, packedLightIn, stack, maid);
        }
    }

    @Environment(EnvType.CLIENT)
    public static void renderBackGun(class_1799 offhandItem, ILocationModel geoModel, IMaid maid, class_4587 poseStack, class_4597 bufferIn, int packedLight) {
        if (INSTALLED && isGun(offhandItem)) {
            poseStack.method_22903();
            GunMaidRender.renderBackGun(offhandItem, geoModel, maid, poseStack, bufferIn, packedLight);
            poseStack.method_22909();
        }
    }

    @Environment(EnvType.CLIENT)
    @Nullable
    public static PlayState playGunMainAnimation(IMaid maid, AnimationEvent<GeckoMaidEntity<?>> event, String animationName, ILoopType loopType) {
        if (INSTALLED && isGun(maid.asEntity().method_6047())) {
            return GunGeckoAnimation.playGunMainAnimation(event, animationName, loopType);
        }
        return null;
    }

    @Environment(EnvType.CLIENT)
    @Nullable
    public static PlayState playGunHoldAnimation(class_1799 mainHandItem, AnimationEvent<GeckoMaidEntity<?>> event) {
        if (INSTALLED && isGun(mainHandItem)) {
            return GunGeckoAnimation.playGunHoldAnimation(event, mainHandItem);
        }
        return null;
    }
}
